@@ -6,47 +6,46 @@
 
 #include "Database.h"
 
-#include <utils/d_ptr_implementation.h>
 #include <common/database/schema/ResourcesDatabaseSchema.h>
+#include <utils/d_ptr_implementation.h>
 
-#include <QSqlDatabase>
-#include <QSqlField>
-#include <QSqlError>
-#include <QSqlDriver>
-#include <QThread>
 #include <QDebug>
+#include <QSqlDatabase>
+#include <QSqlDriver>
+#include <QSqlError>
+#include <QSqlField>
+#include <QThread>
 
-#include <mutex>
 #include <map>
+#include <mutex>
 
 #include "DebugResources.h"
 
-namespace Common {
-
-namespace {
+namespace Common
+{
+namespace
+{
 #ifdef QT_DEBUG
-    QString lastExecutedQuery;
+QString lastExecutedQuery;
 #endif
 
-    std::mutex databases_mutex;
+std::mutex databases_mutex;
 
-    struct DatabaseInfo {
-        Qt::HANDLE thread;
-        Database::OpenMode openMode;
-    };
+struct DatabaseInfo {
+    Qt::HANDLE thread;
+    Database::OpenMode openMode;
+};
 
-    bool operator<(const DatabaseInfo &left, const DatabaseInfo &right)
-    {
-        return
-            left.thread < right.thread     ? true  :
-            left.thread > right.thread     ? false :
-            left.openMode < right.openMode;
-    }
-
-    std::map<DatabaseInfo, std::weak_ptr<Database>> databases;
+bool operator<(const DatabaseInfo &left, const DatabaseInfo &right)
+{
+    return left.thread < right.thread ? true : left.thread > right.thread ? false : left.openMode < right.openMode;
 }
 
-class QSqlDatabaseWrapper {
+std::map<DatabaseInfo, std::weak_ptr<Database>> databases;
+}
+
+class QSqlDatabaseWrapper
+{
 private:
     QSqlDatabase m_database;
     bool m_open;
@@ -56,17 +55,14 @@ public:
     QSqlDatabaseWrapper(const DatabaseInfo &info)
         : m_open(false)
     {
-        m_connectionName =
-                "kactivities_db_resources_"
-                    // Adding the thread number to the database name
-                    + QString::number((quintptr)info.thread)
-                    // And whether it is read-only or read-write
-                    + (info.openMode == Database::ReadOnly ? "_readonly" : "_readwrite");
+        m_connectionName = "kactivities_db_resources_"
+            // Adding the thread number to the database name
+            + QString::number((quintptr)info.thread)
+            // And whether it is read-only or read-write
+            + (info.openMode == Database::ReadOnly ? "_readonly" : "_readwrite");
 
-        m_database =
-            QSqlDatabase::contains(m_connectionName)
-                ? QSqlDatabase::database(m_connectionName)
-                : QSqlDatabase::addDatabase(QStringLiteral("QSQLITE"), m_connectionName);
+        m_database = QSqlDatabase::contains(m_connectionName) ? QSqlDatabase::database(m_connectionName)
+                                                              : QSqlDatabase::addDatabase(QStringLiteral("QSQLITE"), m_connectionName);
 
         if (info.openMode == Database::ReadOnly) {
             m_database.setConnectOptions(QStringLiteral("QSQLITE_OPEN_READONLY"));
@@ -78,9 +74,7 @@ public:
         m_open = m_database.open();
 
         if (!m_open) {
-            qCWarning(KAMD_LOG_RESOURCES) << "KActivities: Database is not open: "
-                                          << m_database.connectionName()
-                                          << m_database.databaseName()
+            qCWarning(KAMD_LOG_RESOURCES) << "KActivities: Database is not open: " << m_database.connectionName() << m_database.databaseName()
                                           << m_database.lastError();
 
             if (info.openMode == Database::ReadWrite) {
@@ -115,7 +109,8 @@ public:
     }
 };
 
-class Database::Private {
+class Database::Private
+{
 public:
     Private()
     {
@@ -153,7 +148,7 @@ Database::Ptr Database::instance(Source source, OpenMode openMode)
 
     // We are saving instances per thread and per read/write mode
     DatabaseInfo info;
-    info.thread   = QThread::currentThreadId();
+    info.thread = QThread::currentThreadId();
     info.openMode = openMode;
 
     // Do we have an instance matching the request?
@@ -207,11 +202,10 @@ Database::Ptr Database::instance(Source source, OpenMode openMode)
     ptr->setPragma(QStringLiteral("wal_autocheckpoint = 100"));
 
     qCDebug(KAMD_LOG_RESOURCES) << "KActivities: Database connection: " << ptr->d->database->connectionName()
-        << "\n    query_only:         " << ptr->pragma(QStringLiteral("query_only"))
-        << "\n    journal_mode:       " << ptr->pragma(QStringLiteral("journal_mode"))
-        << "\n    wal_autocheckpoint: " << ptr->pragma(QStringLiteral("wal_autocheckpoint"))
-        << "\n    synchronous:        " << ptr->pragma(QStringLiteral("synchronous"))
-        ;
+                                << "\n    query_only:         " << ptr->pragma(QStringLiteral("query_only"))
+                                << "\n    journal_mode:       " << ptr->pragma(QStringLiteral("journal_mode"))
+                                << "\n    wal_autocheckpoint: " << ptr->pragma(QStringLiteral("wal_autocheckpoint"))
+                                << "\n    synchronous:        " << ptr->pragma(QStringLiteral("synchronous"));
 
     return ptr;
 }
@@ -260,8 +254,7 @@ QSqlQuery Database::execQuery(const QString &query, bool ignoreErrors) const
 
     if (!ignoreErrors && result.lastError().isValid()) {
         qCWarning(KAMD_LOG_RESOURCES) << "SQL: "
-                   << "\n    error: " << result.lastError()
-                   << "\n    query: " << query;
+                                      << "\n    error: " << result.lastError() << "\n    query: " << query;
     }
 
     return result;
@@ -272,7 +265,7 @@ QSqlQuery Database::execQueries(const QStringList &queries) const
 {
     QSqlQuery result;
 
-    for (const auto &query: queries) {
+    for (const auto &query : queries) {
         result = execQuery(query);
     }
 
