@@ -7,9 +7,9 @@
 
 #include "GlobalShortcutsPlugin.h"
 
-#include <QStringList>
-#include <QString>
 #include <QAction>
+#include <QString>
+#include <QStringList>
 
 #include <KActionCollection>
 #include <KGlobalAccel>
@@ -42,20 +42,15 @@ bool GlobalShortcutsPlugin::init(QHash<QString, QObject *> &modules)
 
     m_activitiesService = modules["activities"];
 
-    m_activitiesList = Plugin::retrieve<QStringList>(
-            m_activitiesService, "ListActivities", "QStringList");
+    m_activitiesList = Plugin::retrieve<QStringList>(m_activitiesService, "ListActivities", "QStringList");
 
-    for (const auto &activity: m_activitiesList) {
+    for (const auto &activity : m_activitiesList) {
         activityAdded(activity);
     }
-    connect(this, SIGNAL(currentActivityChanged(QString)),
-            m_activitiesService, SLOT(SetCurrentActivity(QString)),
-            Qt::QueuedConnection);
+    connect(this, SIGNAL(currentActivityChanged(QString)), m_activitiesService, SLOT(SetCurrentActivity(QString)), Qt::QueuedConnection);
 
-    connect(m_activitiesService, SIGNAL(ActivityAdded(QString)),
-            this, SLOT(activityAdded(QString)));
-    connect(m_activitiesService, SIGNAL(ActivityRemoved(QString)),
-            this, SLOT(activityRemoved(QString)));
+    connect(m_activitiesService, SIGNAL(ActivityAdded(QString)), this, SLOT(activityAdded(QString)));
+    connect(m_activitiesService, SIGNAL(ActivityRemoved(QString)), this, SLOT(activityRemoved(QString)));
 
     m_actionCollection->readSettings();
 
@@ -72,13 +67,14 @@ void GlobalShortcutsPlugin::activityAdded(const QString &activity)
         m_activitiesList << activity;
     }
 
-    const auto action = m_actionCollection->addAction(
-        objectNamePattern.arg(activity));
+    const auto action = m_actionCollection->addAction(objectNamePattern.arg(activity));
 
     action->setText(i18nc("@action", "Switch to activity \"%1\"", activityName(activity)));
     KGlobalAccel::setGlobalShortcut(action, QList<QKeySequence>{});
 
-    connect(action, &QAction::triggered, [this, activity]() { Q_EMIT currentActivityChanged(activity);});
+    connect(action, &QAction::triggered, [this, activity]() {
+        Q_EMIT currentActivityChanged(activity);
+    });
 
     // m_actionCollection->writeSettings();
 }
@@ -93,10 +89,10 @@ void GlobalShortcutsPlugin::activityRemoved(const QString &deletedActivity)
     m_activitiesList.removeAll(deletedActivity);
 
     // Removing all shortcuts that refer to an unknown activity
-    for (const auto &action: m_actionCollection->actions()) {
+    for (const auto &action : m_actionCollection->actions()) {
         const auto actionActivity = activityForAction(action);
-        if ((deletedActivity.isEmpty() && !m_activitiesList.contains(actionActivity))
-                || deletedActivity == actionActivity) {
+        if ((deletedActivity.isEmpty() && !m_activitiesList.contains(actionActivity)) //
+            || deletedActivity == actionActivity) {
             KGlobalAccel::self()->removeAllShortcuts(action);
             m_actionCollection->removeAction(action);
         }
@@ -107,20 +103,16 @@ void GlobalShortcutsPlugin::activityRemoved(const QString &deletedActivity)
 
 void GlobalShortcutsPlugin::activityChanged(const QString &activity)
 {
-    for (const auto &action: m_actionCollection->actions()) {
+    for (const auto &action : m_actionCollection->actions()) {
         if (activity == activityForAction(action)) {
-            action->setText(i18nc("@action", "Switch to activity \"%1\"",
-                                  activityName(activity)));
+            action->setText(i18nc("@action", "Switch to activity \"%1\"", activityName(activity)));
         }
     }
 }
 
 QString GlobalShortcutsPlugin::activityName(const QString &activity) const
 {
-    return Plugin::retrieve<QString>(
-        m_activitiesService, "ActivityName", "QString",
-        Q_ARG(QString, activity));
+    return Plugin::retrieve<QString>(m_activitiesService, "ActivityName", "QString", Q_ARG(QString, activity));
 }
 
 #include "GlobalShortcutsPlugin.moc"
-
